(*
 * The LOOP Project
 *
 * The LOOP Team, Dresden University and Nijmegen University
 *
 * Copyright (C) 2002
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License in file COPYING in this or one of the
 * parent directories for more details.
 *
 * Created 14.5.99 by Hendrik
 *
 * Time-stamp: <Tuesday 21 May 02 18:41:21 tews@ithif51>
 *
 * Liftings and invariance
 *
 * $Id: methodinv_theory.mli,v 1.6 2002/05/22 13:42:41 tews Exp $
 *
 *)

open Classtypes
	 
class ccsl_method_idtype_adt :
  ccsl_iface_type -> ccsl_class_theory_type
			 		    
class ccsl_method_lift_theory :
  ccsl_iface_type -> ccsl_class_theory_type
			 		    
class ccsl_method_invariance_rewrite_theory :
  ccsl_iface_type -> ccsl_class_theory_type

class ccsl_method_invariance_inherit_theory :
  ccsl_iface_type -> ccsl_class_theory_type

class ccsl_box_theory :			    
  ccsl_iface_type -> ccsl_class_theory_type

class ccsl_box_inherit_theory :			    
  ccsl_iface_type -> ccsl_class_theory_type

class ccsl_step_adt : 
  ccsl_iface_type -> ccsl_adt_theory_type

class ccsl_path_theory :
  ccsl_iface_type -> ccsl_class_theory_type


(*** Local Variables: ***)
(*** version-control: t ***)
(*** kept-new-versions: 5 ***)
(*** delete-old-versions: t ***)
(*** time-stamp-line-limit: 30 ***)
(*** End: ***)

